/**
 * @module modelMapper
 * @description This service is used to perform low level model or option transformations before they are sent to the Baasic back-end.
 **/
export declare class ModelMapper {
    idPropertyName: string;
    modelPropertyName: string;
    private utility;
    constructor();
    private FindParams;
    private KeyParams;
    private ModelParams;
    /**
     * Parses Baasic Api pagination, sorting and search parameters.
     * @param options query resources options object
     * @method
     * @example modelMapper.findParams({ pageNumber:1, pageSize:10 });
     **/
    findParams(options?: any): any;
    /**
     * Parses specified key parameters; initial object can be expanded with additional parameters.
     * @param id Resources unique identifier
     * @param options query resources options object
     * @param propName property name
     * @method
     * @example modelMapper.getParams(('<value>', {additionalOptions: '<option>'},'<property-name>'));
     **/
    getParams(id: any, options?: any, propName?: any): any;
    /**
     * Performs create resource transforms on an object so that it can be safely expanded with additional properties.
     * @param data data object
     * @method
     * @example modelMapper.createParams({});
     **/
    createParams(data: any): any;
    /**
     * Performs update resource transforms on transforms an object so that it can be safely expanded with additional properties.
     * @param data data object
     * @method
     * @example modelMapper.updateParams({});
     **/
    updateParams(data: any): any;
    /**
     * Performs remove resource transforms on transforms an object so that it can be safely expanded with additional properties.
     * @param data data object
     * @method
     * @example modelMapper.removeParams({});
     **/
    removeParams(data: any): any;
    /**
 * Performs remove resource transforms on transforms an object so that it can be safely expanded with additional properties.
 * @param data data object
 * @method
 * @example modelMapper.batchRemoveParams({});
 **/
    batchRemoveParams(data: any[]): string[];
}
