/**
 * @module articleCommentRepliesRoute
 * @description Baasic Article Comment Replies Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic Article Comment Replies Route Service to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
 */
import { BaseRoute } from '../../common';
import { IGetRequestOptions, IOptions } from '../../common/contracts';
import { IAppOptions } from '../../core/contracts';
import { IArticleCommentReply } from './contracts';
export declare class ArticleCommentRepliesRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    readonly findRoute: string;
    readonly getRoute: string;
    readonly createRoute: string;
    readonly updateRoute: string;
    readonly deleteRoute: string;
    readonly approveRoute: string;
    readonly unapproveRoute: string;
    readonly flagRoute: string;
    readonly unflagRoute: string;
    readonly reportRoute: string;
    readonly unreportRoute: string;
    readonly spamRoute: string;
    readonly unspamRoute: string;
    constructor(appOptions: IAppOptions);
    /**
     * Parses find route which can be expanded with additional options. Supported items are:
     * - `searchQuery` - A string value used to identify article comment reply resources using the phrase search.
     * - `page` - A value used to set the page number, i.e. to retrieve certain article comment reply subset from the storage.
     * - `rpp` - A value used to limit the size of result set per page.
     * - `sort` - A string used to set the article comment reply property to sort the result collection by.
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * - `statuses` - Comma separated list of article comment reply states that specify where search should be done (Allowed states: Approved, Spam, Reported, Flagged and UnApproved).
     * @method
     * @param options Query resource options object.
     * @example articleCommentRepliesRoute.find({ searchQuery: '<search-phrase>' });
     **/
    find(options: IOptions): any;
    /**
     * Parses get route which can be expanded with additional options. Supported items are:
     * - `id` - Id which uniquely identifies article comment reply resource that needs to be retrieved.
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * @method
     * @param id Id which uniquely identifies article comment reply resource that needs to be retrieved.
     * @param options Options object that contains embed data.
     * @example articleCommentRepliesRoute.get({ id: '<comment-reply-id>' });
     **/
    get(id: string, options?: IGetRequestOptions): any;
    /**
     * Parses create article comment reply route; this URI template does not support any additional items.
     * @method
     * @param data An article comment reply object that needs to be inserted into the system.
     * @example articleCommentRepliesRoute.create(data);
     **/
    create(data: IArticleCommentReply): any;
    /**
     * Parses update article comment reply route; this URI template does not support any additional items.
     * @method
     * @param data An Article Comments Reply object used to update specified article comment reply resource.
     * @example articleCommentRepliesRoute.update(data);
     **/
    update(data: IArticleCommentReply): any;
    /**
    * Parses delete article comment reply route; this URI template does not support any additional items.
    * @method
    * @param data Article Comment Reply object.
    * @example articleCommentRepliesRoute.delete(data);
    **/
    delete(data: IArticleCommentReply): any;
    /**
     * Parses approve article comment reply route; this URI template does not support any additional items.
     * @method
     * @param data Article Comment Reply object.
     * @example articleCommentRepliesRoute.approve(data);
     **/
    approve(data: IArticleCommentReply): any;
    /**
    * Parses unapprove article comment reply route; this URI template does not support any additional items.
    * @method
    * @param data Article Comment Reply object.
    * @example articleCommentRepliesRoute.unapprove(data);
    **/
    unapprove(data: IArticleCommentReply): any;
    /**
    * Parses flag article comment reply route; this URI template does not support any additional items.
    * @method
    * @param data Article Comment Reply object.
    * @example articleCommentRepliesRoute.flag(data);
    **/
    flag(data: IArticleCommentReply): any;
    /**
    * Parses unflag article comment reply route; this URI template does not support any additional items.
    * @method
    * @param data Article Comment Reply object.
    * @example articleCommentRepliesRoute.unflag(data);
    **/
    unflag(data: IArticleCommentReply): any;
    /**
    * Parses report article comment reply route; this URI template does not support any additional items.
    * @method
    * @param data Article Comment Reply object.
    * @example articleCommentRepliesRoute.report(data);
    **/
    report(data: IArticleCommentReply): any;
    /**
    * Parses unreport article comment reply route; this URI template does not support any additional items.
    * @method
    * @param data Article Comment Reply object.
    * @example articleCommentRepliesRoute.unreport(data);
    **/
    unreport(data: IArticleCommentReply): any;
    /**
    * Parses spam article comment reply route; this URI template does not support any additional items.
    * @method
    * @param data Article Comment Reply object.
    * @example articleCommentRepliesRoute.spam(data);
    **/
    spam(data: IArticleCommentReply): any;
    /**
    * Parses unspam article comment reply route; this URI template does not support any additional items.
    * @method
    * @param data Article Comment Reply object.
    * @example articleCommentRepliesRoute.unspam(data);
    **/
    unspam(data: IArticleCommentReply): any;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [REST API documentation](https://github.com/Baasic/baasic-rest-api/wiki) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
*/ 
