/**
 * @module articleFilesBatchRoute
 * @description Baasic Article Files Batch Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic Article Files Batch Route Service to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
*/
import { BaseRoute } from '../../common';
import { IAppOptions } from '../../core/contracts';
export declare class ArticleFilesBatchRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    readonly unlinkRoute: string;
    readonly updateRoute: string;
    readonly linkRoute: string;
    constructor(appOptions: IAppOptions);
    /**
     * Parses unlink route; this URI template does not expose any additional options.
     * @method
     * @example articleFilesBatchRoute.unlink();
     **/
    unlink(): any;
    /**
     * Parses update route; this URI template does not expose any additional options.
     * @method
     * @example articleFilesStreamsRoute.update();
     **/
    update(): any;
    /**
     * Parses update route; this URI template does not expose any additional options.
     * @method
     * @example articleFilesStreamsRoute.link();
     **/
    link(): any;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [REST API documentation](https://github.com/Baasic/baasic-rest-api/wiki) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
*/
