/**
 * @module articleSubscriptionsCommentReportedRoute
 * @description Baasic Article Subscriptions Comment Reported Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic Article Subscriptions Comment Reported Route Definition to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
*/
import { BaseRoute } from '../../../common';
import { IAppOptions } from '../../../core/contracts';
import { IArticleSubscription } from '../contracts';
export declare class ArticleSubscriptionsCommentReportedRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    readonly subscribeRoute: string;
    readonly isSubscribedRoute: string;
    readonly unSubscribeRoute: string;
    constructor(appOptions: IAppOptions);
    /**
     * Parses commentReported subscribe route which doesn't support any additional options.
     * @method
     * @param data The subscribe information.
     * @example articleSubscriptionsCommentReportedRoute.subscribe(data);
     **/
    subscribe(data: IArticleSubscription): any;
    /**
     * Parses commentReported isSubscribed route which must be expanded with subscriber Id.
     * @method
     * @param data The subscribe information.
     * @example articleSubscriptionsCommentReportedRoute.isSubscribed({subscriberId: '<subscriber-id>'});
     **/
    isSubscribed(data: IArticleSubscription): any;
    /**
     * Parses commentReported unSubscribe route which doesn't support any additional options.
     * @method
     * @param data The unsubscribe information.
     * @example articleSubscriptionsCommentReportedRoute.unSubscribe(data);
     **/
    unSubscribe(data: IArticleSubscription): any;
}
