/**
 * @module baasicArticleTagsSubscriptionsDefinition
 * @description  Article Tags Subscriptions Definition provides an easy way to consume  Article Tags REST API end-points. `articleTagsDefinition` functions enable performing standard CRUD operations directly on article tag resources, whereas the `articleClient` functions allow management between article and article tag. In order to obtain needed routes `articleTagsDefinition` uses `articleTagsRoute`.
*/
import { ApiClient, IHttpResponse } from '../../httpApi';
import { ArticleTagsSubscriptionsRoute } from './';
import { IArticleTag, IArticleSubscription } from './contracts';
export declare class ArticleTagsSubscriptionsClient {
    protected articleTagsSubscriptionsRoute: ArticleTagsSubscriptionsRoute;
    protected apiClient: ApiClient;
    readonly routeDefinition: ArticleTagsSubscriptionsRoute;
    constructor(articleTagsSubscriptionsRoute: ArticleTagsSubscriptionsRoute, apiClient: ApiClient);
    /**
     * Returns a promise that is resolved once the subscribe action has been performed. This action subscribes an user to the specified tag.
     * @method
     * @param tag article tag object.
     * @param data The subscribe information.
     * @returns A promise that is resolved once the subscribe action has been performed.
     * @example articleTagsSubscriptionsClient.subscribe(tag, user)
                    .then(function (data) {
                        // perform success action here
                    },
                     function (response, status, headers, config) {
                        // perform error handling here
                    });
     **/
    subscribe(tag: IArticleTag, data: any): PromiseLike<IHttpResponse<IArticleSubscription>>;
    /**
     * Returns a promise that is resolved once the isSubscribed action has been performed. This action checks if a user is subscribed to the specified tag.
     * @method
     * @param tag Article tag object.
     * @param data The subscriber identifier.
     * @returns A promise that is resolved once the isSubscribed action has been performed.
     * @example articleTagsSubscriptionsClient.isSubscribed(tag, user)
                    .then(function (data) {
                        // perform success action here
                    },
                     function (response, status, headers, config) {
                        // perform error handling here
                    });
     **/
    isSubscribed(tag: IArticleTag, data: any): PromiseLike<IHttpResponse<IArticleSubscription>>;
    /**
     * Returns a promise that is resolved once the unSubscribe action has been performed. This action unsubscribes a user from the specified tag.
     * @method
     * @param tag Article tag object.
     * @param data The unsubscribe information.
     * @returns A promise that is resolved once the unSubscribe action has been performed.
     * @example articleTagsSubscriptionsClient.unSubscribe(tag, user)
                   .then(function (data) {
                       // perform success action here
                   },
                    function (response, status, headers, config) {
                       // perform error handling here
                   });
    **/
    unSubscribe(tag: IArticleTag, data: any): PromiseLike<IHttpResponse<void>>;
}
/**
 * @copyright (c) 2017 Mono Ltd
 * @license MIT
 * @author Mono Ltd
 * @overview
 ***Notes:**
 - Refer to the [Baasic REST API](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
 - All end-point objects are transformed by the associated route service.
*/
