/**
 * @module calendarACLRoute
 * @description Baasic Calendar ACL Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic Calendar ACL Route Definition to obtain a needed routes while other routes will be obtained through HAL. By convention, all route services  use the same function names as their corresponding services.
 */
import { BaseRoute } from '../../../common';
import { IACLOptions, IACLPolicy } from '../../../common/contracts';
import { IAppOptions } from '../../../core/contracts';
export declare class CalendarACLRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    readonly getRoute: string;
    readonly updateRoute: string;
    readonly deleteByUserRoute: string;
    readonly deleteByRoleRoute: string;
    constructor(appOptions: IAppOptions);
    /**
     * Parses get calendar acl route; this URI template should be expanded with the Id of the calnedar.
     * @method
     * @param options ACL options object.
     * @example calendarACLRoute.get({id: '<id>'});
     */
    get(options: IACLOptions): any;
    /**
     * Parses update calendar acl route; this URI template should be expanded with the Id of the calnedar.
     * @method
     * @param options ACL options object.
     * @example calendarACLRoute.update({id: '<id>'});
     */
    update(options: IACLOptions): any;
    /**
     * Parses deleteByUser calendar acl route which can be expanded with additional options. Supported items are:
     * - `id` - Id of the user calnedar data resource.
     * - `accessAction` - Action abbreviation which identifies ACL policy assigned to the specified user and calendar resource.
     * - `user` - A value which uniquely identifies user for which ACL policy needs to be removed.
     * @method
     * @param id user calnedar data id which uniquely identifies user calnedar data resource whose security privileges need to be retrieved and updated.
     * @param action Action abbreviation which identifies ACL policy assigned to the specified user and user calnedar data resource.
     *               Supported Values:
     *               "Create"
     *               "Delete"
     *               "Read"
     *               "Update"
     * @param user A value that uniquely identifies user for which ACL policy needs to be removed.
     * @param data ACL Policy object used to delete specified item in the system.
     * @example calendarACLRoute.deleteByUser({
                    id: '<id>',
                    accessAction: '<access-action>',
                    user: '<username>'
                });
     */
    deleteByUser(id: string, action: string, user: string, data: IACLPolicy): any;
    /**
     * Parses deleteByUser calendar acl route which can be expanded with additional options. Supported items are:
     * - `id` - Id of the calendar.
     * - `accessAction` - Action abbreviation which identifies ACL policy assigned to the specified role and calendar resource.
     * - `role` - A value which uniquely identifies role for which ACL policy needs to be removed.
     * @method
     * @param id User calendar data id which uniquely identifies user calendar data resource whose security privileges need to be retrieved and updated.
     * @param action Action abbreviation which identifies ACL policy assigned to the specified user and user calendar data resource.
     *               Supported Values:
     *               "Create"
     *               "Delete"
     *               "Read"
     *               "Update"
     * @param role A value that uniquely identifies role for which ACL policy needs to be removed.
     * @param data ACL Policy object used to delete specified item in the system.
     * @example calendarACLRoute.deleteByRole({ id: '<id>', accessAction: '<access-action>', role: '<role-name>'});
     */
    deleteByRole(id: string, action: string, role: string, data: IACLPolicy): any;
    updateParams(data: any): any;
}
/**
 * @copyright (c) 2017 Mono Ltd
 * @license MIT
 * @author Mono Ltd
 * @overview
 ***Notes:**
  - Refer to the [Baasic REST API](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
  - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
  - All end-point objects are transformed by the associated route service.
 */ 
