/**
 * @module calendarEventRsvpAttendeeRoute
 * @description BaasicCalendarEventRsvpAttendeeRoute Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use BaasicCalendarEventRsvpAttendeeRoute Definition to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
 */
import { BaseRoute } from '../../../common';
import { IGetRequestOptions } from '../../../common/contracts';
import { IAppOptions } from '../../../core/contracts';
import { ICalendarEvent, ICalendarEventAttendee, IGetCalendarEventAttendeeOptions } from '../contracts';
export declare class CalendarEventRsvpAttendeeRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    readonly findRoute: string;
    readonly getRoute: string;
    readonly createRoute: string;
    readonly updateRoute: string;
    readonly deleteRoute: string;
    readonly purgeRoute: string;
    readonly updateStatusRoute: string;
    readonly updateStatusEmailOrFullNameRoute: string;
    readonly subscribeRoute: string;
    readonly unsubscribeRoute: string;
    constructor(appOptions: IAppOptions);
    /**
     * Parses find route which can be expanded with additional GetCalendarLookupOptions. Supported items are:
     * - `searchQuery` - A string referencing CalendarEventAttendee properties using the phrase or BQL (Baasic Query Language) search.
     * - `page` - A value used to set the page number, i.e. to retrieve certain CalendarEventAttendee subset from the storage.
     * - `rpp` - A value used to limit the size of result set per page.
     * - `sort` - A string used to set the CalendarEventAttendee property to sort the result collection by.
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * - `calendarIds` - calendar ids which identify CalendarEventAttendee resources.
     * - `calendarNames` - calendar names which identify CalendarEventAttendee resources.
     * - `eventIds` - eventIds which identify CalendarEventAttendee resources.
     * - `invitationTypeIds` - invitationTypeIds which identify CalendarEventAttendee resources.
     * - `attendeeStatusIds` - statusIds which identify CalendarEventAttendee resources.
     * - `userIds` - CalendarEventAttende userIds which identify CalendarEventAttendee resources.
     * - `slotDifference` - Slot difference.
     * - `emails` - CalendarEventAttendee emails which identify CalendarEventAttendee resources.
     * - `from` - Fluent syntax for 'From' date. Used to limit the dataset to only use resources starting from this date.
     * - `to` - Fluent syntax for 'To' date. Used to limit the dataset to only use resources ending to this date.
     * - `ids` - CalendarEventAttendee ids which uniquely identify CalendarEventAttendee resources that need to be retrieved.
     * @method
     * @param options Query resource GetCalendarLookupOptions object.
     * @example calendarEventRsvpAttendeeRoute.find({searchQuery: '<search-phrase>'});
     */
    find(options?: IGetCalendarEventAttendeeOptions): any;
    /**
     * Parses get route which must be expanded with the id of the previously created CalendarEventAttendee resource in the system. The route can be expanded using additional GetRequestOptions. Supported items are
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * @method
     * @param id CalendarEventAttendee id which uniquely identifies CalendarEventAttendee resource that needs to be retrieved.
     * @param options Query resource GetRequestOptions object.
     * @example calendarEventRsvpAttendeeRoute.get(id);
     */
    get(id: string, options?: IGetRequestOptions): any;
    /**
     * Parses create route. This URI template does not expose any additional options.
     * @method
     * @param data A CalendarEventAttendee object that needs to be inserted into the system.
     * @example calendarEventRsvpAttendeeRoute.create(data);
     */
    create(data: ICalendarEventAttendee): any;
    /**
     * Parses update route. This URI template does not expose any additional options.
     * @method
     * @param data A CalendarEventAttendee object used to update specified CalendarEventAttendee resource.
     * @example calendarEventRsvpAttendeeRoute.update(data);
     */
    update(data: ICalendarEventAttendee): any;
    /**
    * Parses update status email or name route. This URI template does not expose any additional options.
    * @method
    * @param id A CalendarEventAttendee identifier which uniquely identifies CalendarEventAttendee resource.
    * @param statusId A calendarEventAttendeeStatus identifier which uniquely identifies CalendarEventAttendee resource.
    * @example calendarEventRsvpAttendeeRoute.update(id, statusId);
    */
    updateStatus(id: string, statusId: string): any;
    /**
    * Parses update status email or name route. This URI template does not expose any additional options.
    * @method
    * @param id A CalendarEventAttendee identifier which uniquely identifies CalendarEventAttendee resource.
    * @param emailOrFullName Email or full name
    * @param statusId A calendarEventAttendeeStatus identifier which uniquely identifies CalendarEventAttendee resource.
    * @example calendarEventRsvpAttendeeRoute.update(id, email, statusId);
    */
    updateStatusEmailOrFullName(id: string, emailOrFullName: string, statusId: string): any;
    /**
     * Parses delte route. This URI template does not expose any additional options.
     * @method
     * @param data A CalendarEventAttendee object used to delete specified CalendarEventAttendee resource.
     * @example calendarEventRsvpAttendeeRoute.delete(data);
     */
    delete(data: ICalendarEventAttendee): any;
    /**
     * Parses subscribe route. This URI template does not expose any additional options.
     * @method
     * @param id CalendarEventAttendee id which uniquely identifies a CalendarEventAttendee resource.
     * @example calendarEventRsvpAttendeeRoute.subscribe(attendeeId);
     */
    subscribe(id: string): any;
    /**
     * Parses unsubscribe route. This URI template does not expose any additional options.
     * @method
     * @param id CalendarEventAttendee id which uniquely identifies a CalendarEventAttendee resource.
     * @example calendarEventRsvpAttendeeRoute.unsubscribe(attendeeId);
     */
    unsubscribe(id: string): any;
    /**
     * Parses purge route. This URI template does not expose any additional options.
     * @method
     * @example calendarEventRsvpAttendeeRoute.purge();
     */
    purge(event: ICalendarEvent): any;
    protected getToDate(options: any): any;
    protected getFromDate(options: any): any;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [REST API documentation](https://github.com/Baasic/baasic-rest-api/wiki) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
 */ 
