/**
 * @module calendarEventStatusBatchClient
 * @description  CalendarEventStatusBatchClient provides an easy way to consume CalendarEventStatusBatch REST API end-points. In order to obtain needed routes `calendarEventStatusBatchClient` uses `calendarEventStatusBatchRoute`.
 */
import { ApiClient, IHttpResponse } from '../../../../httpApi';
import { CalendarEventStatusBatchRoute } from '../../';
import { ICalendarEventStatus } from '../../contracts';
export declare class CalendarEventStatusBatchClient {
    protected calendarEventStatusBatchRoute: CalendarEventStatusBatchRoute;
    protected apiClient: ApiClient;
    readonly routeDefinition: CalendarEventStatusBatchRoute;
    constructor(calendarEventStatusBatchRoute: CalendarEventStatusBatchRoute, apiClient: ApiClient);
    /**
     * Returns a promise that is resolved once the create CalendarEventStatuses action has been performed. This action creates new CalendarEventStatus resources.
     * @method
     * @param data CalendarEventStatus objects that need to be inserted into the system.
     * @returns A promise that is resolved once the create CalendarEventStatuses action has been performed.
     * @example calendarEventStatusBatchClient.create([{
                    abrv: '<abrv>',
                    json: '<json>',
                    name: '<name>'
                }])
                .then(function (data) {
                    // perform success action here
                },
                function (response, status, headers, config) {
                    // perform error handling here
                });
     */
    create(data: ICalendarEventStatus[]): PromiseLike<IHttpResponse<ICalendarEventStatus[]>>;
    /**
     * Returns a promise that is resolved once the update CalendarEventStatuses action has been performed. This action updates CalendarEventStatuse resources.
     * @method
     * @param data CalendarEventStatus objects used to update specified CalendarEventStatus resources.
     * @returns A promise that is resolved once the update CalendarEventStatuses action has been performed.
     * @example calendarEventStatuses are resources previously fetched using get action.
                calendarEventStatusBatchClient.update(calendarEventStatuses)
                .then(function (data) {
                    // perform success action here
                },
                function (response, status, headers, config) {
                    // perform error handling here
                });
     */
    update(data: ICalendarEventStatus[]): PromiseLike<IHttpResponse<void>>;
    /**
     * Returns a promise that is resolved once the remove action has been performed. This action will remove CalendarEventStatus resources from the system if successfully completed.
     * @method
     * @param data CalendarEventStatus Ids which uniquely identify CalendarEventStatus resources to be deleted.
     * @returns A promise that is resolved once the remove action has been performed.
     * @example calendarEventStatusIds are identifiers which uniquely identify CalendarEventStatus resources.
                calendarEventStatusBatchClient.remove(calendarEventStatusIds)
                .then(function (data) {
                    // perform success action here
                },
                function (response, status, headers, config) {
                    // perform error handling here
                });
     */
    remove(data: string[]): PromiseLike<IHttpResponse<void>>;
}
/**
 * @copyright (c) 2017 Mono Ltd
 * @license MIT
 * @author Mono Ltd
 * @overview
 ***Notes:**
 - Refer to the [Baasic REST API](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
 - All end-point objects are transformed by the associated route definition.
 */ 
