/**
 * @module calendarEventTypeBatchClient
 * @description  CalendarEventTypeBatchClient provides an easy way to consume CalendarEventTypeBatch REST API end-points. In order to obtain needed routes `calendarEventTypeBatchClient` uses `calendarEventTypeBatchRoute`.
 */
import { ApiClient, IHttpResponse } from '../../../../httpApi';
import { CalendarEventTypeBatchRoute } from '../../';
import { ICalendarEventType } from '../../contracts';
export declare class CalendarEventTypeBatchClient {
    protected calendarEventTypeBatchRoute: CalendarEventTypeBatchRoute;
    protected apiClient: ApiClient;
    readonly routeDefinition: CalendarEventTypeBatchRoute;
    constructor(calendarEventTypeBatchRoute: CalendarEventTypeBatchRoute, apiClient: ApiClient);
    /**
     * Returns a promise that is resolved once the create CalendarEventTypes action has been performed; this action creates new CalendarEventType resources.
     * @method
     * @param data CalendarEventType objects that need to be inserted into the system.
     * @returns A promise that is resolved once the create CalendarEventTypes action has been performed.
     * @example calendarEventTypeBatchClient.create([{
                    abrv: '<abrv>',
                    json: '<json>',
                    name: '<name>'
                }])
                .then(function (data) {
                    // perform success action here
                },
                function (response, status, headers, config) {
                    // perform error handling here
                });
     */
    create(data: ICalendarEventType[]): PromiseLike<IHttpResponse<ICalendarEventType[]>>;
    /**
     * Returns a promise that is resolved once the update CalendarEventTypes action has been performed; this action updates CalendarEventType resources.
     * @method
     * @param data CalendarEventType objects used to update specified CalendarEventType resources.
     * @returns A promise that is resolved once the update CalendarEventTypes action has been performed.
     * @example calendarEventTypes are resources previously fetched using get action.
                calendarEventTypeBatchClient.update(calendarEventTypes)
                .then(function (data) {
                    // perform success action here
                },
                function (response, status, headers, config) {
                    // perform error handling here
                });
    */
    update(data: ICalendarEventType[]): PromiseLike<IHttpResponse<void>>;
    /**
     * Returns a promise that is resolved once the remove action has been performed. This action will remove CalendarEventType resources from the system if successfully completed.
     * @method
     * @param data CalendarEventType Ids which uniquely identify CalendarEventType resources to be deleted.
     * @returns A promise that is resolved once the remove action has been performed.
     * @example calendarEventTypeIds are identifiers which uniquely identify CalendarEventType resources.
                calendarEventTypeBatchClient.remove(calendarEventTypeIds)
                .then(function (data) {
                    // perform success action here
                },
                function (response, status, headers, config) {
                    // perform error handling here
                });
     */
    remove(data: string[]): PromiseLike<IHttpResponse<void>>;
}
/**
 * @copyright (c) 2017 Mono Ltd
 * @license MIT
 * @author Mono Ltd
 * @overview
 ***Notes:**
 - Refer to the [Baasic REST API](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
 - All end-point objects are transformed by the associated route definition.
 */ 
