/**
 * @module commerceCouponRoute
 * @description Baasic Commerce Coupon Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic Commerce Coupon Route Definition to obtain a needed routes while other routes will be obtained through HAL. By convention, all route services  use the same function names as their corresponding services.
 */
import { BaseRoute } from '../../../common';
import { IGetRequestOptions } from '../../../common/contracts';
import { IAppOptions } from '../../../core/contracts';
import { ICouponOptions } from '../contracts';
export declare class CommerceCouponRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    readonly findRoute: string;
    readonly getRoute: string;
    readonly createRoute: string;
    readonly updateRoute: string;
    readonly deleteRoute: string;
    readonly findCouponUseRoute: string;
    constructor(appOptions: IAppOptions);
    /**
     * Parses find commerce coupon route which can be expanded with additional options. Supported items are:
     * - `searchQuery` - A string value used to identify commerce resources using the phrase search.
     * - `page` - A value used to set the page number, i.e. to retrieve certain commerce subset from the storage.
     * - `rpp` - A value used to limit the size of result set per page.
     * - `sort` - A string used to set the commerce property to sort the result collection by.
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * - `productId` - A product id.
     * - `productCategoryId` - A product category id.
     * - `active` - flag is coupon active or not
     * @method
     * @example commerceCouponRoute.find({searchQuery: '<search-phrase>'});
     **/
    find(options?: ICouponOptions): any;
    /**
     * Parses get route; this route doesn't expose any properties.
     * @method
     * @example commerceCouponRoute.get(id, options);
     **/
    get(id: string, options?: IGetRequestOptions): any;
    /**
     * Parses create commerce coupon route; this URI template does not expose any additional options.
     * @method
     * @example commerceCouponRoute.create();
     **/
    create(): any;
    /**
     * Parses update commerce coupon route; this URI template does not expose any additional options.
     * @method
     * @example commerceCouponRoute.update(data);
     **/
    update(data: any): any;
    /**
    * Parses delete commerce coupon route; this URI template does not expose any additional options.
    * @method
    * @example commerceCouponRoute.delete(data);
    **/
    delete(data: any): any;
    /**
     * Parses find route; this route doesn't expose any properties.
     * @method
     * @example commerceCouponRoute.findCouponUses(couponId, options);
     **/
    findCouponUses(couponId: string, options?: IGetRequestOptions): any;
}
/**
 * @copyright (c) 2017 Mono Ltd
 * @license MIT
 * @author Mono Ltd
 * @overview
 ***Notes:**
 - Refer to the [Baasic REST API](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
 */ 
