/**
 * @module commerceLookupsCouponTypeBatchClient
 * @description  Commerce Lookups Address Type Batch Client provides an easy way to consume  Commerce REST API end-points. In order to obtain a needed routes `commerceLookupsCouponTypesBatchClient` uses `commerceLookupsCouponTypeBatchRoute`.
 */
import { ApiClient, IHttpResponse } from '../../../../httpApi';
import { CommerceLookupsCouponTypeBatchRoute } from '../../';
export declare class CommerceLookupsCouponTypesBatchClient {
    protected commerceLookupsCouponTypeBatchRoute: CommerceLookupsCouponTypeBatchRoute;
    protected apiClient: ApiClient;
    readonly routeDefinition: CommerceLookupsCouponTypeBatchRoute;
    constructor(commerceLookupsCouponTypeBatchRoute: CommerceLookupsCouponTypeBatchRoute, apiClient: ApiClient);
    /**
     * Returns a promise that is resolved once the create commerce action has been performed; this action creates a new commerce resources.
     * @method
     * @example commerceLookupsCouponTypeBatchClient.create([{
                     name : '<name>',
                     abrv: '<abbreviation>',
                     description: '<description>'
                    }])
                    .then(function (data) {
                        // perform success action here
                    },
                     function (response, status, headers, config) {
                         // perform error handling here
                    });
     **/
    create(data: any): PromiseLike<IHttpResponse<any>>;
    /**
     * Returns a promise that is resolved once the update commerce action has been performed; this action updates specified commerce resources.
     * @method
     * @example   commerceLookupsCouponTypeBatchClient.update(commerceCouponTypes)
                       .then(function (data) {
                           // perform success action here
                       },
                        function (response, status, headers, config) {
                            // perform error handling here
                       });
    **/
    update(data: any): PromiseLike<IHttpResponse<void>>;
    /**
     * Returns a promise that is resolved once the remove commerce action has been performed. This action will remove commerce resources from the system if successfully completed.
     * @method
     * @example commerceLookupsCouponTypeClient.remove(commerceCouponTypeIds)
                    .then(function (data) {
                        // perform success action here
                    },
                     function (response, status, headers, config) {
                         // perform error handling here
                    });
     **/
    remove(ids: string[]): PromiseLike<IHttpResponse<void>>;
}
/**
 * @copyright (c) 2017 Mono Ltd
 * @license MIT
 * @author Mono Ltd
 * @overview
 ***Notes:**
 - Refer to the [Baasic REST API](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
 - All end-point objects are transformed by the associated route service.
 */ 
