/**
 * @module commerceLookupsCouponTypeClient
 * @description  Commerce Lookups Coupon Type Client provides an easy way to consume  Commerce REST API end-points. In order to obtain a needed routes `commerceLookupsCouponTypesClient` uses `commerceLookupsCouponTypeRoute`.
 */
import { IQueryModel, IGetRequestOptions, IOptions } from '../../../../common/contracts';
import { ApiClient, IHttpResponse } from '../../../../httpApi';
import { CommerceLookupsCouponTypesBatchClient, CommerceLookupsCouponTypeRoute } from '../../';
export declare class CommerceLookupsCouponTypesClient {
    protected commerceLookupsCouponTypeRoute: CommerceLookupsCouponTypeRoute;
    protected commerceLookupsCouponTypesBatchClient: CommerceLookupsCouponTypesBatchClient;
    protected apiClient: ApiClient;
    readonly routeDefinition: CommerceLookupsCouponTypeRoute;
    readonly batch: CommerceLookupsCouponTypesBatchClient;
    constructor(commerceLookupsCouponTypeRoute: CommerceLookupsCouponTypeRoute, commerceLookupsCouponTypesBatchClient: CommerceLookupsCouponTypesBatchClient, apiClient: ApiClient);
    /**
     * Returns a promise that is resolved once the find action has been performed. Success response returns a list of commerce resources matching the given criteria.
     * @method
     * @example commerceLookupsCouponTypeClient.find({
                    pageNumber : 1,
                    pageSize : 10,
                    orderBy : '<field>',
                    orderDirection : '<asc|desc>',
                    search : '<search-phrase>'
                })
                .then(function (collection) {
                    // perform success action here
                },
                 function (response, status, headers, config) {
                     // perform error handling here
                });
     **/
    find(options?: IOptions): PromiseLike<IHttpResponse<IQueryModel<any>>>;
    /**
     * Returns a promise that is resolved once the get action has been performed. Success response returns the commerce resource.
     * @method
     * @example commerceLookupsCouponTypeClient.get()
                   .then(function (data) {
                       // perform success action here
                   },
                    function (response, status, headers, config) {
                        // perform error handling here
                   });
    **/
    get(id: string, options?: IGetRequestOptions): PromiseLike<IHttpResponse<any>>;
    /**
     * Returns a promise that is resolved once the create commerce action has been performed; this action creates a new commerce resource.
     * @method
     * @example commerceLookupsCouponTypeClient.create({
                       name : '<name>',
                       abrv: '<abbreviation>',
                       description: '<description>'
                   })
                   .then(function (data) {
                       // perform success action here
                   },
                    function (response, status, headers, config) {
                        // perform error handling here
                   });
    **/
    create(data: any): PromiseLike<IHttpResponse<any>>;
    /**
     * Returns a promise that is resolved once the update commerce action has been performed; this action updates a commerce resource. This route uses HAL enabled objects to obtain routes and therefore it doesn't apply `commerceLookupsCouponTypeRoute` route template. Here is an example of how a route can be obtained from HAL enabled objects:
     * ```
     * let params = modelMapper.removeParams(commerceCouponType);
     * let uri = params['model'].links('put').href;
     * ```
     * @method
     * @example // commerceCouponType is a resource previously fetched using get action.
                    commerceCouponType.description = '<description>';
                    commerceLookupsCouponTypeClient.update(commerceCouponType)
                        .then(function (data) {
                            // perform success action here
                        },
                         function (response, status, headers, config) {
                             // perform error handling here
                        });
     **/
    update(data: any): PromiseLike<IHttpResponse<void>>;
    /**
     * Returns a promise that is resolved once the remove action has been performed. This action will remove a commerce resource from the system if successfully completed. This route uses HAL enabled objects to obtain routes and therefore it doesn't apply `commerceLookupsCouponTypeRoute` route template. Here is an example of how a route can be obtained from HAL enabled objects:
     * ```
     * let params = modelMapper.removeParams(commerceCouponType);
     * let uri = params['model'].links('delete').href;
     * ```
     * @method
     * @example // commerceCouponType is a resource previously fetched using get action.
                    commerceLookupsCouponTypeClient.remove(commerceCouponType)
                        .then(function (data) {
                            // perform success action here
                        },
                         function (response, status, headers, config) {
                             // perform error handling here
                        });
     **/
    remove(data: any): PromiseLike<IHttpResponse<void>>;
}
/**
 * @copyright (c) 2017 Mono Ltd
 * @license MIT
 * @author Mono Ltd
 * @overview
 ***Notes:**
 - Refer to the [Baasic REST API](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
 - All end-point objects are transformed by the associated route service.
 */ 
