/**
 * @module commerceLookupsCouponTypeRoute
 * @description Baasic Commerce Lookups CouponType Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic Commerce Lookups CouponType Route Definition to obtain a needed routes while other routes will be obtained through HAL. By convention, all route services  use the same function names as their corresponding services.
 */
import { BaseRoute } from '../../../../common';
import { IGetRequestOptions, IOptions } from '../../../../common/contracts';
import { IAppOptions } from '../../../../core/contracts';
import { CommerceLookupsCouponTypeBatchRoute } from '../../';
export declare class CommerceLookupsCouponTypeRoute extends BaseRoute {
    protected commerceLookupsCouponTypeBatchRoute: CommerceLookupsCouponTypeBatchRoute;
    protected appOptions: IAppOptions;
    readonly findRoute: string;
    readonly getRoute: string;
    readonly createRoute: string;
    readonly updateRoute: string;
    readonly deleteRoute: string;
    readonly batch: CommerceLookupsCouponTypeBatchRoute;
    constructor(commerceLookupsCouponTypeBatchRoute: CommerceLookupsCouponTypeBatchRoute, appOptions: IAppOptions);
    /**
     * Parses find commerce coupon type route which can be expanded with additional options. Supported items are:
     * - `searchQuery` - A string value used to identify commerce resources using the phrase search.
     * - `page` - A value used to set the page number, i.e. to retrieve certain commerce subset from the storage.
     * - `rpp` - A value used to limit the size of result set per page.
     * - `sort` - A string used to set the commerce property to sort the result collection by.
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * @method
     * @example commerceLookupsCouponTypeRoute.find({searchQuery: '<search-phrase>'});
     **/
    find(options?: IOptions): any;
    /**
     * Parses get route; this route doesn't expose any properties.
     * @method
     * @example commerceLookupsCouponTypeRoute.get(id, options);
     **/
    get(id: string, options?: IGetRequestOptions): any;
    /**
     * Parses create commerce coupon type route; this URI template does not expose any additional options.
     * @method
     * @example commerceLookupsCouponTypeRoute.create();
     **/
    create(): any;
    /**
     * Parses update commerce coupon type route; this URI template does not expose any additional options.
     * @method
     * @example commerceLookupsCouponTypeRoute.update(data);
     **/
    update(data: any): any;
    /**
     * Parses delete commerce coupon type route; this URI template does not expose any additional options.
     * @method
     * @example commerceLookupsCouponTypeRoute.delete(data);
     **/
    delete(data: any): any;
}
/**
 * @copyright (c) 2017 Mono Ltd
 * @license MIT
 * @author Mono Ltd
 * @overview
 ***Notes:**
 - Refer to the [Baasic REST API](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
 */ 
