/**
 * @module commerceProductInstanceFilesBatchRoute
 * @description Baasic Product Instance Files Batch Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic Product Files Batch Route Service to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
*/
import { BaseRoute } from '../../../../common';
import { IAppOptions } from '../../../../core/contracts';
export declare class CommerceProductInstanceFilesBatchRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    readonly unlinkRoute: string;
    readonly updateRoute: string;
    readonly linkRoute: string;
    constructor(appOptions: IAppOptions);
    /**
     * Parses unlink route; this URI template does not expose any additional options.
     * @method
     * @param productId Product file id of the original product file used to identify product files on which delete action should be performed.
     * @example productInstanceFilesBatchRoute.unlink(productId);
     **/
    unlink(productId: string): any;
    /**
     * Parses update route; this URI template does not expose any additional options.
     * @method
     * @param productId Product id which uniquely identifies product whose product file need to be updated.
     * @example productInstanceFilesStreamsRoute.update(productId);
     **/
    update(productId: string): any;
    /**
     * Parses update route; this URI template does not expose any additional options.
     * @method
     * @param productId Product slug or id which uniquely identifies product whose product files need to be linked.
     * @example productInstanceFilesStreamsRoute.link(productId);
     **/
    link(productId: string): any;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [REST API documentation](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
*/
