/**
 * @module filesBatchRoute
 * @description Baasic Files Batch Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic Files Route Definition to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
 */
import { BaseRoute } from '../../common';
import { IAppOptions } from '../../core/contracts';
export declare class FilesBatchRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    readonly updateRoute: string;
    readonly linkRoute: string;
    readonly unlinkRoute: string;
    constructor(appOptions: IAppOptions);
    /**
     * Parses update route; this URI template does not expose any additional options.
     * @method
     * @example filesBatchRoute.update();
     **/
    update(): any;
    /**
     * Parses update route; this URI template does not expose any additional options.
     * @method
     * @example filesBatchRoute.link();
     **/
    link(): any;
    /**
     * Parses unlink route; this URI template does not expose any additional options.
     * @method
     * @example filesBatchRoute.unlink();
     **/
    unlink(): any;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [REST API documentation](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
 */ 
