/**
 * @module mediaGalleryInstanceFilesRoute
 * @description Baasic Media Gallery Instance Files Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic Media Gallery Files Route Service to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
*/
import { BaseRoute } from '../../../common';
import { IGetRequestOptions } from '../../../common/contracts';
import { IAppOptions } from '../../../core/contracts';
import { MediaGalleryInstanceFilesBatchRoute } from '../';
import { IMediaGalleryFile, IMediaGalleryOptions } from '../contracts';
export declare class MediaGalleryInstanceFilesRoute extends BaseRoute {
    protected mediaGalleryInstanceFilesBatchRoute: MediaGalleryInstanceFilesBatchRoute;
    protected appOptions: IAppOptions;
    readonly findRoute: string;
    readonly getRoute: string;
    readonly linkRoute: string;
    readonly unlinkRoute: string;
    readonly unlinkByMediaGalleryRoute: string;
    readonly updateRoute: string;
    readonly batch: MediaGalleryInstanceFilesBatchRoute;
    constructor(mediaGalleryInstanceFilesBatchRoute: MediaGalleryInstanceFilesBatchRoute, appOptions: IAppOptions);
    /**
     * Parses find route which can be expanded with additional options. Supported items are:
     * - `searchQuery` - A string referencing file properties using the phrase search.
     * - `page` - A value used to set the page number, i.e. to retrieve certain file subset from the storage.
     * - `rpp` - A value used to limit the size of result set per page.
     * - `sort` - A string used to set the file property to sort the result collection by.
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * @method
     * @param mediaGalleryId Media Gallery slug or id which uniquely identifies media gallery whose media gallery files need to be retrieved.
     * @param options Query resource options object.
     * @example mediaGalleryInstanceFilesRoute.find({searchQuery: '<search-phrase>'});
     **/
    find(mediaGalleryId: string, options?: IMediaGalleryOptions): any;
    /**
     * Parses get route; this route should be expanded with the Id of the file resource.
     * @method
     * @param mediaGalleryId Media Gallery id which uniquely identifies media gallery whose media gallery files need to be retrieved.
     * @param id Media Gallery file id which uniquely identifies media gallery file that needs to be retrieved.
     * @param options options object that contains embed data.
     * @example mediaGalleryInstanceFilesRoute.get({id: '<file-id>'});
     **/
    get(mediaGalleryId: string, id: string, options?: IGetRequestOptions): any;
    /**
     * Parses link route; this URI template does not expose any additional options.
     * @method
     * @param mediaGalleryId Media Gallery id which uniquely identifies media gallery whose media gallery files need to be deleted.
     * @param data
     * @param options
     * @example mediaGalleryInstanceFilesRoute.link();
     **/
    link(mediaGalleryId: string, data: IMediaGalleryFile): any;
    /**
     * Parses unlink route; this URI template does not expose any additional options.
     * @method
     * @param mediaGalleryId Media Gallery id which uniquely identifies gallery whose gallery files need to be deleted.
     * @param data
     * @example mediaGalleryFilesRoute.unlink(mediaGalleryId,data);
     **/
    unlink(mediaGalleryId: string, data: IMediaGalleryFile): any;
    /**
     * Parses unlink by media gallery route; this URI template does not expose any additional options.
     * @method
     * @param mediaGalleryId Media Gallery id which uniquely identifies media gallery whose media gallery files need to be deleted.
     * @param data
     * @param options
     * @example mediaGalleryFilesRoute.unlinkByMediaGallery(data);
     **/
    unlinkByMediaGallery(mediaGalleryId: string, options?: any): any;
    /**
     * Parses update route; this URI template does not expose any additional options.
     * @method
     * @example mediaGalleryInstanceFilesRoute.update(data);
     **/
    update(mediaGalleryId: string, data: IMediaGalleryFile): any;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [REST API documentation](https://github.com/Baasic/baasic-rest-api/wiki) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
*/ 
