/**
 * @module mediaVaultProcessingProviderSettingsRoute
 * @description Baasic Media Vault Processing Provider Settings Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic Media Vault Processing Provider Settings Route Definition to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
 */
import { BaseRoute } from '../../common';
import { IGetRequestOptions, IOptions } from '../../common/contracts';
import { IPreprocessingProviderSettings } from './contracts';
import { IAppOptions } from '../../core/contracts';
export declare class MediaVaultProcessingProviderSettingsRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    readonly findRoute: string;
    readonly getRoute: string;
    readonly updateRoute: string;
    constructor(appOptions: IAppOptions);
    /**
     * Parses find route which can be expanded with additional options. Supported items are:
     * - `searchQuery` - A string referencing media vault processing provider setting properties using the phrase search.
     * - `page` - A value used to set the page number, i.e. to retrieve certain media vault processing provider setting subset from the storage.
     * - `rpp` - A value used to limit the size of result set per page.
     * - `sort` - A string used to set the media vault processing provider setting property to sort the result collection by.
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * @method
     * @example mediaVaultProcessingProviderSettingsRoute.find({searchQuery: '<search-phrase>'});
     **/
    find(options?: IOptions): any;
    /**
     * Parses get route; this route should be expanded with Id of the media vault processing provider setting resource.
     * @method
     * @example mediaVaultProcessingProviderSettingsRoute.get({id: '<id>'});
     **/
    get(id: string, options?: IGetRequestOptions): any;
    /**
     * Parses update route; this route should be expanded with Id of the media vault processing provider setting resource.
     * @method
     * @param data A media vault preprocessing provider settings object used to update specified media vault preprocessing provider settings in the system.
     * @example mediaVaultProcessingProviderSettingsRoute.update(data);
     **/
    update(data: IPreprocessingProviderSettings): any;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [REST API documentation](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
 */ 
