/**
 * @module mediaVaultRoute
 * @description Baasic Media Vault Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic Media Vault Route Service to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
 */
import { BaseRoute } from '../../common';
import { IGetRequestOptions, IOptions } from '../../common/contracts';
import { MediaVaultBatchRoute, MediaVaultProcessingProviderSettingsRoute, MediaVaultSettingsRoute, MediaVaultStreamsRoute } from './';
import { IMediaEntry } from './contracts';
import { IAppOptions } from '../../core/contracts';
export declare class MediaVaultRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    protected mediaVaultStreamsRoute: MediaVaultStreamsRoute;
    protected mediaVaultBatchRoute: MediaVaultBatchRoute;
    protected mediaVaultSettingsRoute: MediaVaultSettingsRoute;
    protected mediaVaultProcessingProviderSettingsRoute: MediaVaultProcessingProviderSettingsRoute;
    readonly findRoute: string;
    readonly getRoute: string;
    readonly updateRoute: string;
    readonly deleteRoute: string;
    readonly streams: MediaVaultStreamsRoute;
    readonly batch: MediaVaultBatchRoute;
    readonly settings: MediaVaultSettingsRoute;
    readonly processingProviderSettings: MediaVaultProcessingProviderSettingsRoute;
    constructor(appOptions: IAppOptions, mediaVaultStreamsRoute: MediaVaultStreamsRoute, mediaVaultBatchRoute: MediaVaultBatchRoute, mediaVaultSettingsRoute: MediaVaultSettingsRoute, mediaVaultProcessingProviderSettingsRoute: MediaVaultProcessingProviderSettingsRoute);
    /**
     * Parses find route which can be expanded with additional options. Supported items are:
     * - `searchQuery` - A string referencing media vault properties using the phrase search.
     * - `page` - A value used to set the page number, i.e. to retrieve certain media vault subset from the storage.
     * - `rpp` - A value used to limit the size of result set per page.
     * - `sort` - A string used to set the media vault property to sort the result collection by.
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * @method
     * @param options Query resource options object.
     * @example mediaVaultRoute.find({searchQuery: '<search-phrase>'});
     **/
    find(options?: IOptions): any;
    /**
     * Parses get route; this route should be expanded with the Id of media vault resource.
     * @method
     * @param id Media vault id which uniquely identifies media vault resource that needs to be retrieved.
     * @param options Query resource options object.
     * @example mediaVaultRoute.get({id: '<media-vault-id>'});
     **/
    get(id: string, options?: IGetRequestOptions): any;
    /**
     * Parses update route; this route should be expanded with the Id of media vault resource.
     * @method
     * @param data Media vault object used to update specific Media vault resource in the system.
     * @example mediaVaultRoute.get({id: '<media-vault-id>'});
     **/
    update(data: IMediaEntry): any;
    /**
     * Parses delete route; this route should be expanded with the Id of media vault resource.
     * @method
     * @param data Media vault object used to update specific Media vault resource in the system.
     * @param options Options object.
     * @example mediaVaultRoute.delete({id: '<media-vault-id>'});
     **/
    delete(data: IMediaEntry, options?: Object): any;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [REST API documentation](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
 */ 
