/**
 * @module notificationsRoute
 * @description Baasic Notifications Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic Notifications Route Definition to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
 */
import { BaseRoute } from '../../common';
import { IAppOptions } from '../../core/contracts';
import { NotificationsPublishRoute, NotificationsSubscriptionsRoute, NotificationsRegistrationsRoute, NotificationsSettingsRoute } from './';
export declare class NotificationsRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    protected notificationsPublishRoute: NotificationsPublishRoute;
    protected basicNotificationsSubscriptionsRoute: NotificationsSubscriptionsRoute;
    protected notificationsRegistrationsRoute: NotificationsRegistrationsRoute;
    protected notificationsSettingsRoute: NotificationsSettingsRoute;
    readonly publish: NotificationsPublishRoute;
    readonly subscriptions: NotificationsSubscriptionsRoute;
    readonly registrations: NotificationsRegistrationsRoute;
    readonly settings: NotificationsSettingsRoute;
    constructor(appOptions: IAppOptions, notificationsPublishRoute: NotificationsPublishRoute, basicNotificationsSubscriptionsRoute: NotificationsSubscriptionsRoute, notificationsRegistrationsRoute: NotificationsRegistrationsRoute, notificationsSettingsRoute: NotificationsSettingsRoute);
}
/**
 * @overview
 ***Notes:**
 - Refer to the [REST API documentation](https://github.com/Baasic/baasic-rest-api/wiki) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
 */ 
