/**
 * @module notificationsSubscriptionsUsersRoute
 * @description Baasic Notifications Subscriptions Users Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic Notifications Route Definition to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
 */
import { BaseRoute } from '../../common';
import { IGetRequestOptions, IOptions } from '../../common/contracts';
import { IAppOptions } from '../../core/contracts';
import { NotificationsSubscriptionsUsersBatchRoute } from './';
import { IUserSubscription } from './contracts';
export declare class NotificationsSubscriptionsUsersRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    protected notificationsSubscriptionsUsersBatchRoute: NotificationsSubscriptionsUsersBatchRoute;
    readonly createRoute: string;
    readonly findRoute: string;
    readonly getRoute: string;
    readonly deleteRoute: string;
    readonly updateRoute: string;
    batch(): NotificationsSubscriptionsUsersBatchRoute;
    constructor(appOptions: IAppOptions, notificationsSubscriptionsUsersBatchRoute: NotificationsSubscriptionsUsersBatchRoute);
    /**
     * Parses create user subscription route; this route does not expose any additional options
     * @method
     * @example notificationsSubscriptionsUsersRoute.create();
     */
    create(): any;
    /**
     * Parses find user subscriptions route which can be expanded with additional options. Supported items are:
     * - `searchQuery` - A string referencing user subscription properties using the phrase search.
     * - `userIds` - Comma separated list of user identifiers.
     * - `channels` - Comma separated list of channels.
     * - `page` - A value used to set the page number, i.e. to retrieve certain user subscriptions subset from the storage.
     * - `rpp` - A value used to limit the size of result set per page.
     * - `sort` - A string used to set the user subscription property to sort the result collection by.
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * @method
     * @example notificationsSubscriptionsUsersRoute.find({ searchQuery: '<search-phrase>', channels: '<channel-name>,<channel-name>' });
     */
    find(options?: IOptions): any;
    /**
     * Parses get user subscription route; this route should be expanded with the Id of user subscription resource.
     * @method
     * @param id The subscription identifier which uniquely identifies UserSubscription resource that needs to be retrieved.
     * @param options Query resource options object.
     * @example notificationsSubscriptionsUsersRoute.get({ id: '<subscription-id>' });
     */
    get(id: string, options?: IGetRequestOptions): any;
    /**
     * Parses delete user subscription route; this route should be expanded with the Id of user subscription resource.
     * @method
     * @param data An object used to delete specified UserSubscription resource.
     * @example notificationsSubscriptionsUsersRoute.delete(data);
     */
    delete(data: IUserSubscription): any;
    /**
     * Parses update user subscription route; this route should be expanded with the Id of user subscription resource.
     * @method
     * @param data An object used to update specified UserSubscription resource.
     * @example notificationsSubscriptionsUsersRoute.update(data);
     */
    update(data: IUserSubscription): any;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [REST API documentation](https://github.com/Baasic/baasic-rest-api/wiki) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
 */ 
