/**
 * @module userProfileAvatarRoute
 * @description Baasic User Profile Avatar Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic User Profile Avatar Route Definition to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
 */
import { BaseRoute } from '../../common';
import { IGetRequestOptions } from '../../common/contracts';
import { UserProfileAvatarStreamsRoute } from './';
import { IProfileAvatar } from './contracts';
import { IAppOptions } from '../../core/contracts';
export declare class UserProfileAvatarRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    protected userProfileAvatarStreamsRoute: UserProfileAvatarStreamsRoute;
    readonly getRoute: string;
    readonly updateRoute: string;
    readonly linkRoute: string;
    readonly unlinkRoute: string;
    readonly streams: UserProfileAvatarStreamsRoute;
    constructor(appOptions: IAppOptions, userProfileAvatarStreamsRoute: UserProfileAvatarStreamsRoute);
    /**
     * Parses get route; this route should be expanded with the Id of the profile.
     * @method
     * @param id User Profile id which uniquely identifies user avatar resource that needs to be retrieved.
     * @param options Query resource options object.
     * @example userProfileAvatarRoute.get({id: '<file-id>'});
     **/
    get(id: string, options?: IGetRequestOptions): any;
    /**
     * Parses update route; this URI template does not expose any additional options.
     * @method
     * @param data A Profile Avatar object used to update specified Profile Avatar resource.
     * @example userProfileAvatarRoute.update(data);
     **/
    update(data: IProfileAvatar): any;
    /**
     * Parses link route; this route should be expanded with the Id of the profile.
     * @method
     * @param id User Profile id which uniquely identifies user avatar resource that needs to be retrieved.
     * @param data A Profile Avatar object used to link specified Profile Avatar resource.
     * @example userProfileAvatarRoute.link({id: '<file-id>'});
     **/
    link(id: string, data: IProfileAvatar): any;
    /**
     * Parses link route; this route should be expanded with the Id of the profile.
     * @method
     * @param data A Profile Avatar object used to unlink specified Profile Avatar resource.
     * @param options Query resource options object.
     * @example userProfileAvatarRoute.unlink(data);
     **/
    unlink(data: IProfileAvatar, options?: any): any;
    createParams(data: any, id: string): any;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [REST API documentation](https://github.com/Baasic/baasic-rest-api/wiki) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
 */ 
