/**
 * @module settingsClient
 * @description  Settings Client provides an easy way to consume  Password Recovery REST API end-points. In order to obtain needed routes `settingsClient` uses `settingsRoute`.
*/
import { ApiClient, IHttpResponse } from '../../../httpApi';
import { SettingsRoute } from './';
import { IApplicationSettings } from './contracts';
export declare class SettingsClient {
    protected settingsRoute: SettingsRoute;
    protected apiClient: ApiClient;
    /**
     * Provides direct access to `settingsRoute`.
     * @method
     **/
    readonly routeDefinition: SettingsRoute;
    constructor(settingsRoute: SettingsRoute, apiClient: ApiClient);
    /**
     * Returns a promise that is resolved once the get action has been performed. Success response returns the application settings.
     * @method
     * @returns A promise that is resolved once the get action has been performed.
     * @example settingsClient.get()
                .then(function (data) {
                    // perform success action here
                },
                 function (response, status, headers, config) {
                    // perform error handling here
                });
     **/
    get(): PromiseLike<IHttpResponse<IApplicationSettings>>;
    /**
     * Returns a promise that is resolved once the update application setting action has been performed; this action updates a application seting.
     * @param data A setting object used to update specified setting resource.
     * @returns A promise that is resolved once the update setting action has been performed.
     * @method
     * @example settingsClient.update(data)
                        .then(function (data) {
                            // perform success action here
                        },
                         function (response, status, headers, config) {
                            // perform error handling here
                        });
     **/
    update(data: IApplicationSettings): PromiseLike<IHttpResponse<any>>;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [Baasic REST API](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
 - All end-point objects are transformed by the associated route service.
*/ 
