/**
 * @module versionClient
 * @description  Version Client provides an easy way to consume  Password Recovery REST API end-points. In order to obtain needed routes `versionClient` uses `versionRoute`.
*/
import { ApiClient, IHttpResponse } from '../../../httpApi';
import { VersionRoute } from './';
import { IModuleVersion } from './contracts';
export declare class VersionClient {
    protected versionRoute: VersionRoute;
    protected apiClient: ApiClient;
    /**
     * Provides direct access to `versionRoute`.
     * @method
     **/
    readonly routeDefinition: VersionRoute;
    constructor(versionRoute: VersionRoute, apiClient: ApiClient);
    /**
     * Returns a promise that is resolved once the get action has been performed. Success response returns the all application module versions.
     * @method
     * @returns A promise that is resolved once the get action has been performed.
     * @example versionClient.get()
                .then(function (data) {
                    // perform success action here
                },
                 function (response, status, headers, config) {
                    // perform error handling here
                });
     **/
    get(): PromiseLike<IHttpResponse<IModuleVersion[]>>;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [Baasic REST API](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
 - All end-point objects are transformed by the associated route service.
*/ 
