/**
 * @module roleRoute
 * @description Baasic Role Batch Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic Role Route Service to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
 */
import { BaseRoute } from '../../../common';
import { IAppOptions } from '../../../core/contracts';
export declare class RoleBatchRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    /**
    * Create route with route and query parameters.
    **/
    createRoute: string;
    /**
    * Update route with route and query parameters.
    **/
    updateRoute: string;
    /**
    * Delete route with route and query parameters.
    **/
    removeRoute: string;
    constructor(appOptions: IAppOptions);
    /**
     * Parses create batch roles route; this URI template does not expose any additional options.
     * @method
     * @example roleBatchRoute.create();
     **/
    create(): any;
    /**
     * Parses update batch roles route.
     * @method
     * @param data A role object used to update specified role resource.
     * @example roleBatchRoute.update(data);
     */
    update(): any;
    /**
     * Parses delete batch roles route.
     * @method
     * @param data A role object used to delete specified role resource.
     * @example roleBatchRoute.delete(data);
     */
    delete(): any;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [Baasic REST API](http://dev.baasic.com/api/reference/home) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route definition.
*/ 
