/**
 * @module notificationsRegistrationsUsersRoute
 * @description Baasic Notifications Registrations Users Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic Notifications Registrations Users Route Definition to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
 */
import { BaseRoute } from '../../../common';
import { IGetRequestOptions, IOptions } from '../../../common/contracts';
import { IAppOptions } from '../../../core/contracts';
import { NotificationsRegistrationsUsersBatchRoute } from './';
import { IUserRegistration } from './contracts';
export declare class NotificationsRegistrationsUsersRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    protected notificationsRegistrationsUsersBatchRoute: NotificationsRegistrationsUsersBatchRoute;
    readonly createRoute: string;
    readonly findRoute: string;
    readonly getRoute: string;
    readonly deleteRoute: string;
    readonly updateRoute: string;
    readonly batch: NotificationsRegistrationsUsersBatchRoute;
    constructor(appOptions: IAppOptions, notificationsRegistrationsUsersBatchRoute: NotificationsRegistrationsUsersBatchRoute);
    /**
     * Parses create users registrations route; this route does not expose any additional options
     * @method
     * @example notificationsRegistrationsUsersRoute.create();
     */
    create(): any;
    /**
     * Parses find users registrations route which can be expanded with additional options. Supported items are:
     * - `searchQuery` - A string referencing user subscription properties using the phrase search.
     * - `userIds` - Comma separated list of user identifiers.
     * - `providers` - Comma separated list of notification providers.
     * - `page` - A value used to set the page number, i.e. to retrieve certain user subscription subset from the storage.
     * - `rpp` - A value used to limit the size of result set per page.
     * - `sort` - A string used to set the user subscription property to sort the result collection by.
     * - `embed` - Comma separated list of resources to be contained within the current representation.
     * @method
     * @param options Query resource options object.
     * @example notificationsRegistrationsUsersRoute.find({ searchQuery: '<search-phrase>', providers: '<provider-name>,<provider-name>' });
     */
    find(options?: IOptions): any;
    /**
     * Parses get users registrations route; this route should be expanded with the Id of users registrations resource.
     * @method
     * @param id The registration identifier which uniquely identifies UserRegistration resource that needs to be retrieved.
     * @param options Query resource options object.
     * @example notificationsRegistrationsUsersRoute.get({ id: '<registration-id>' });
     */
    get(id: string, options?: IGetRequestOptions): any;
    /**
     * Parses delete users registrations route; this route should be expanded with the Id of users registrations resource.
     * @method
     * @param data An object used to delete specified UserRegistration resource.
     * @example notificationsRegistrationsUsersRoute.delete(data);
     */
    delete(data: IUserRegistration): any;
    /**
     * Parses update users registrations route; this route should be expanded with the Id of users registrations resource.
     * @method
     * @param data An object used to update specified UserRegistration resource.
     * @example notificationsRegistrationsUsersRoute.update(data);
     */
    update(data: IUserRegistration): any;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [REST API documentation](https://github.com/Baasic/baasic-rest-api/wiki) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
 */ 
