/**
 * @module userProfileAvatarStreamsRoute
 * @description Baasic User Profile Avatar Streams Route Definition provides Baasic route templates which can be expanded to Baasic REST URIs. Various services can use Baasic User Profile Avatar Streams Route Definition to obtain needed routes while other routes will be obtained through HAL. By convention, all route services use the same function names as their corresponding services.
 */
import { BaseRoute } from '../../../common';
import { IAppOptions } from '../../../core/contracts';
export declare class UserProfileAvatarStreamsRoute extends BaseRoute {
    protected appOptions: IAppOptions;
    readonly getRoute: string;
    readonly createRoute: string;
    readonly updateRoute: string;
    constructor(appOptions: IAppOptions);
    /**
     * Parses get route; this route should be expanded with id of profile. Additional supported items are:
     * - `width` - width of desired derived image.
     * - `height` - height of desired derived image.
     * - `t` - cache invalidation param.
     * @method
     * @example userProfileAvatarStreamsRoute.get({id: '<file-id>'});
     **/
    get(data: any): any;
    /**
     * Parses create route; this route should be expanded with the filename which indicates where the stream will be saved as well with id of the profile.
     * @method
     * @example userProfileAvatarStreamRoute.create({ filename: '<filename>', id: '<file-id>' });
     **/
    create(id: string, data: any): any;
    /**
     * Parses update route; this route should be expanded with the id of the profile. Additional supported items are:
     * - `width` - width of derived image to update.
     * - `height` - height of derived image to update.
     * @method
     * @param data
     * @example userProfileAvatarStreamsRoute.update({id: '<file-id>'});
     **/
    update(data: any): any;
}
/**
 * @overview
 ***Notes:**
 - Refer to the [REST API documentation](https://github.com/Baasic/baasic-rest-api/wiki) for detailed information about available Baasic REST API end-points.
 - [URI Template](https://github.com/Baasic/uritemplate-js) syntax enables expanding the Baasic route templates to Baasic REST URIs providing it with an object that contains URI parameters.
 - All end-point objects are transformed by the associated route service.
 */ 
